@@ -87,7 +87,7 @@ def auth_width(model, repo):
 # in following lambdas, r is a hg repo
 # it return the longuest entry of this column
 _maxwidth = {'ID': lambda self, r: str(len(r.changelog)),
-             'Date': lambda self, r: cvrt_date(r.changectx(0).date()),
+             'Date': lambda self, r: cvrt_date(r[0].date()),
              'Branch': lambda self, r: ([None] + sorted(allbranches(r), key=len))[-1],
              'Author': lambda self, r: 'author name',
              'Filename': lambda self, r: self.filename,
@@ -226,7 +226,7 @@ class HgRepoListModel(QAbstractTableModel, HgRepoListWalker):
         self.ensureBuilt(row=row)
         column = self._columns[index.column()]
         gnode = self.graph[row]
-        ctx = self.repo.changectx(gnode.rev)
+        ctx = self.repo[gnode.rev]
         if role == Qt.DisplayRole:
             if column == 'Author': #author
                 user = _columnmap[column](self, ctx, gnode) if ctx.node() else u'' 
@@ -269,7 +269,7 @@ class HgRepoListModel(QAbstractTableModel, HgRepoListWalker):
                 return COLOR_BG_HIGHLIGHT[row % 2]
             elif ctx.obsolete():
                 return COLOR_BG_OBSOLETE[row % 2]
-            elif ctx.troubles():
+            elif ctx.instabilities():
                 return COLOR_BG_TROUBLED[row % 2]
 
     def headerData(self, section, orientation, role):
@@ -685,7 +685,7 @@ class ManifestModel(QAbstractItemModel):
         QAbstractItemModel.__init__(self, parent)
 
         self.repo = repo
-        self.changectx = self.repo.changectx(rev)
+        self.changectx = self.repo[rev]
         self.setupModelData()
 
     def data(self, index, role):
